window.Gleam.initSearch([{"doc":"gsv","title":"gsv","content":"# gsv\n\n[![Package Version](https://img.shields.io/hexpm/v/gsv)](https://hex.pm/packages/gsv)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gsv/)\n\nA simple csv parser and serialiser for Gleam.\n\n```gleam\nimport gsv.{Unix, Windows}\n\npub fn main() {\n  let csv =\n    &quot;name,loves\nlucy,gleam&quot;\n\n  // Parse a csv string into a list of rows.\n  let assert Ok(rows) = gsv.to_lists(csv)\n  // -&gt; [[&quot;name&quot;, &quot;loves&quot;], [&quot;lucy&quot;, &quot;gleam&quot;]]\n\n  // If your csv has headers you can also parse it into a list of dictionaries.\n  let assert Ok(rows) = gsv.to_dicts(csv_str)\n  // -&gt; dict.from_list([#(&quot;name&quot;, &quot;lucy&quot;), #(&quot;loves&quot;, &quot;gleam&quot;)])\n}\n```\n\n## Installation\n\nTo add this package to your Gleam project:\n\n```sh\ngleam add gsv@3\n```\n","url":"index.html"},{"doc":"gsv","title":"LineEnding","content":"pub type LineEnding {\n  Windows\n  Unix\n}\n Possible line endings used when turning a parsed csv back into a string\n with the `from_lists` and `from_dicts` functions.\n\nWindows\n The CRLF line ending: `\\r\\n`.\n\n\nUnix\n The LF line ending: `\\n`.\n\nSynonyms:\ngsv.LineEnding\ngsv LineEnding","url":"gsv.html#LineEnding"},{"doc":"gsv","title":"ParseError","content":"pub type ParseError {\n  UnescapedQuote(position: Int)\n  UnclosedEscapedField(start: Int)\n}\n\nUnescapedQuote(position: Int)\n This error can occur if there is a csv field contains an unescaped double\n quote `&quot;`.\n\n A field can contain a double quote only if it is escaped (that is,\n surrounded by double quotes). For example `wibb&quot;le` would be an invalid\n field, the correct way to write such a field would be like this:\n `&quot;wibb&quot;&quot;le&quot;`.\n\nposition\n&lt;p&gt;The byte index of the unescaped double.&lt;/p&gt;\n\nUnclosedEscapedField(start: Int)\n This error can occur when the file ends without the closing `&quot;` of an\n escaped field. For example: `&quot;hello`.\n\nstart\n&lt;p&gt;The byte index of the start of the unclosed escaped field.&lt;/p&gt;\n\nSynonyms:\ngsv.ParseError\ngsv ParseError","url":"gsv.html#ParseError"},{"doc":"gsv","title":"from_dicts","content":"pub fn from_dicts(\n  rows: List(Dict(String, String)),\n  separator separator: String,\n  line_ending line_ending: LineEnding,\n) -&gt; String\n Takes a list of dicts and writes it to a csv string.\n Will automatically escape strings that contain double quotes or\n line endings with double quotes (in csv, double quotes get escaped by doing\n a double doublequote)\n The string `he&quot;llo\\n` becomes `&quot;he&quot;&quot;llo\\n&quot;`\n\nSynonyms:\ngsv.from_dicts\ngsv from_dicts","url":"gsv.html#from_dicts"},{"doc":"gsv","title":"from_lists","content":"pub fn from_lists(\n  rows: List(List(String)),\n  separator separator: String,\n  line_ending line_ending: LineEnding,\n) -&gt; String\n Takes a list of lists of strings and turns it to a csv string, automatically\n escaping all fields that contain double quotes or line endings.\n\n ## Examples\n\n \n let rows = [[&quot;hello&quot;, &quot;world&quot;], [&quot;goodbye&quot;, &quot;mars&quot;]]\n from_lists(rows, separator: &quot;,&quot;, line_ending: Unix)\n // &quot;hello,world\n // goodbye,mars&quot;\n \n\n \n let rows = [[]]\n \n\nSynonyms:\ngsv.from_lists\ngsv from_lists","url":"gsv.html#from_lists"},{"doc":"gsv","title":"to_dicts","content":"pub fn to_dicts(\n  input: String,\n) -&gt; Result(List(Dict(String, String)), ParseError)\n Parses a csv string into a list of dicts: the first line of the csv is\n interpreted as the headers&#39; row and each of the following lines is turned\n into a dict with a value for each of the headers.\n\n If a field is empty then it won&#39;t be added to the dict.\n\n ## Examples\n\n \n &quot;pet,name,cuteness\n dog,Fido,100\n cat,,1000\n &quot;\n |&gt; gsv.to_dicts\n // Ok([\n //    dict.from_list([\n //      #(&quot;pet&quot;, &quot;dog&quot;), #(&quot;name&quot;, &quot;Fido&quot;), #(&quot;cuteness&quot;, &quot;100&quot;)\n //    ]),\n //    dict.from_list([\n //      #(&quot;pet&quot;, &quot;cat&quot;), #(&quot;cuteness&quot;, &quot;1000&quot;)\n //    ]),\n // ])\n \n\n &gt; Just list `to_lists` this implementation tries to stick as closely as\n &gt; possible to [RFC4180](https://www.ietf.org/rfc/rfc4180.txt).\n &gt; You can look at `to_lists`&#39; documentation to see how it differs from the\n &gt; RFC.\n\nSynonyms:\ngsv.to_dicts\ngsv to_dicts","url":"gsv.html#to_dicts"},{"doc":"gsv","title":"to_lists","content":"pub fn to_lists(\n  input: String,\n) -&gt; Result(List(List(String)), ParseError)\n Parses a csv string into a list of lists of strings: each line of the csv\n will be turned into a list with an item for each field.\n\n ## Examples\n\n \n &quot;hello, world\n goodbye, mars&quot;\n |&gt; gsv.to_lists\n // Ok([\n //    [&quot;hello&quot;, &quot; world&quot;],\n //    [&quot;goodbye&quot;, &quot; mars&quot;],\n // ])\n \n\n &gt; This implementation tries to stick as closely as possible to\n &gt; [RFC4180](https://www.ietf.org/rfc/rfc4180.txt), with a couple notable\n &gt; convenience differences:\n &gt; - both `\\n` and `\\r\\n` line endings are accepted.\n &gt; - a line can start with an empty field `,two,three`.\n &gt; - empty lines are allowed and just ignored.\n &gt; - lines are not forced to all have the same number of fields.\n &gt; - a line can end with a comma (meaning its last field is empty).\n\nSynonyms:\ngsv.to_lists\ngsv to_lists","url":"gsv.html#to_lists"},{"doc":"gsv","title":"gsv","content":"","url":"gsv.html"}]);